@@ -60,7 +60,7 @@ Links
 More information on the M61 model can be found in the:
 
     - U{relax wiki<http://wiki.nmr-relax.com/M61>},
-    - U{relax manual<http://www.nmr-relax.com/manual/M61_2_site_fast_exchange_R1_model.html>},
+    - U{relax manual<http://www.nmr-relax.com/manual/The_M61_2_site_fast_exchange_R1_rho_model.html>},
     - U{relaxation dispersion page of the relax website<http://www.nmr-relax.com/analyses/relaxation_dispersion.html#M61>}.
 """
 
