@@ -114,9 +114,6 @@ class MolContainer:
             if self.atom_num[j] == atom_num:
                 return j
 
-        # Should not be here, the PDB connect records are incorrect.
-        warn(RelaxWarning("The atom number " + repr(atom_num) + " from the CONECT record cannot be found within the ATOM and HETATM records."))
-
 
     def _det_pdb_element(self, atom_name):
         """Try to determine the element from the PDB atom name.
@@ -258,6 +255,44 @@ class MolContainer:
         return fields
 
 
+    def _sort(self):
+        """Sort all structural data."""
+
+        # Create an index list for sorting the structural data.
+        indices = list(range(len(self.atom_name)))
+        indices.sort(key=self._sort_key)
+
+        # Sort all lists.
+        self.atom_num = [self.atom_num[i] for i in indices]
+        self.atom_name = [self.atom_name[i] for i in indices]
+        self.bonded = [self.bonded[i] for i in indices]
+        self.chain_id = [self.chain_id[i] for i in indices]
+        self.element = [self.element[i] for i in indices]
+        self.pdb_record = [self.pdb_record[i] for i in indices]
+        self.res_name = [self.res_name[i] for i in indices]
+        self.res_num = [self.res_num[i] for i in indices]
+        self.seg_id = [self.seg_id[i] for i in indices]
+        self.x = [self.x[i] for i in indices]
+        self.y = [self.y[i] for i in indices]
+        self.z = [self.z[i] for i in indices]
+
+        # Change the bonded numbers, as the indices are now different.
+        for i in range(len(self.bonded)):
+            for j in range(len(self.bonded[i])):
+                self.bonded[i][j] = indices.index(self.bonded[i][j])
+
+
+    def _sort_key(self, i):
+        """Return the information for sorting the sequence data."""
+
+        # Python 3 - return 0 instead of None.
+        if self.res_num[i] == None:
+            return 0
+
+        # Sort based on residue number.
+        return self.res_num[i]
+
+
     def atom_add(self, atom_name=None, res_name=None, res_num=None, pos=[None, None, None], element=None, atom_num=None, chain_id=None, segment_id=None, pdb_record=None):
         """Method for adding an atom to the structural data object.
 
@@ -359,6 +394,8 @@ class MolContainer:
         """
 
         # Loop over the records.
+        water = []
+        missing_connect = []
         for record in records:
             # Nothing to do.
             if not record or record == '\n':
@@ -372,6 +409,11 @@ class MolContainer:
                 if record[:6] == 'HETATM':
                     record_type, serial, name, alt_loc, res_name, chain_id, res_seq, icode, x, y, z, occupancy, temp_factor, element, charge = pdb_read.hetatm(record)
 
+                # Skip waters.
+                if res_name == 'HOH':
+                    water.append(res_seq)
+                    continue
+
                 # Handle the alternate locations.
                 if alt_loc != None:
                     # Don't know what to do.
@@ -400,12 +442,29 @@ class MolContainer:
                     if not bonded:
                         continue
 
+                    # The atom indices.
+                    serial_index = self._atom_index(serial)
+                    bonded_index = self._atom_index(bonded)
+
                     # Skip broken CONECT records (for when the record points to a non-existent atom).
-                    if self._atom_index(serial) == None or self._atom_index(bonded) == None:
+                    if serial_index == None:
+                        if serial not in missing_connect:
+                            missing_connect.append(serial)
+                        continue
+                    if bonded_index == None:
+                        if bonded not in missing_connect:
+                            missing_connect.append(bonded)
                         continue
 
                     # Make the connection.
-                    self.atom_connect(index1=self._atom_index(serial), index2=self._atom_index(bonded))
+                    self.atom_connect(index1=serial_index, index2=bonded_index)
+
+        # Warnings.
+        if len(missing_connect):
+            missing_connect.sort()
+            warn(RelaxWarning("The following atom numbers from the CONECT records cannot be found within the ATOM and HETATM records:  %s." % missing_connect))
+        if len(water):
+            warn(RelaxWarning("Skipping the water molecules HOH %s." % water))
 
 
     def fill_object_from_xyz(self, records):
