@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2013-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2013-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -22,7 +22,7 @@
 # Module docstring.
 """Module for creating PDB records.
 
-This module currently used the PDB format version 3.30 from July, 2011 U{http://www.wwpdb.org/documentation/format33/v3.3.html}.
+This module currently used the PDB format version 3.30 from July, 2011 U{http://www.wwpdb.org/documentation/file-format/format33/v3.3.html}.
 """
 
 # Python module imports.
@@ -32,6 +32,40 @@ from textwrap import wrap
 from lib.errors import RelaxError
 
 
+def _handle_atom_name(name):
+    """Handle the funky PDB atom name alignment.
+
+    From the PDB format documents:
+
+        - "Alignment of one-letter atom name such as C starts at column 14, while two-letter atom name such as FE starts at column 13."
+
+
+    @param name:    The atom name.
+    @type name:     str or None
+    @return:        The whitespace padded and PDB formatted atom name.  This will be exactly 4 characters.
+    @rtype:         str
+    """
+
+    # Handle none.
+    if name == None:
+        name = "    "
+
+    # Single letter name.
+    if len(name) == 1:
+        name = " %s  " % name
+
+    # Two letter name.
+    elif len(name) == 2:
+        name = "%s  " % name
+
+    # Three letter name.
+    elif len(name) == 3:
+        name = "%s " % name
+
+    # Return the name.
+    return name
+
+
 def _handle_none(value):
     """Auxiliary function for handling values of None.
 
@@ -92,7 +126,7 @@ def _record_validate(record):
 def atom(file, serial='', name='', alt_loc='', res_name='', chain_id='', res_seq='', icode='', x='', y='', z='', occupancy=1.0, temp_factor=0.0, element='', charge=''):
     """Generate the ATOM record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect9.html#ATOM}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect9.html#ATOM}.
 
     ATOM
     ====
@@ -283,7 +317,7 @@ def atom(file, serial='', name='', alt_loc='', res_name='', chain_id='', res_seq
     text = "%-6s%5s %-4s%1s%3s %1s%4s%1s   %8.3f%8.3f%8.3f%6.2f%6.2f          %2s%2s" % (
         'ATOM',
         _handle_none(serial),
-        _handle_none(name),
+        _handle_atom_name(name),
         _handle_none(alt_loc),
         _handle_none(res_name),
         _handle_none(chain_id),
@@ -309,7 +343,7 @@ def atom(file, serial='', name='', alt_loc='', res_name='', chain_id='', res_seq
 def conect(file, serial='', bonded1='', bonded2='', bonded3='', bonded4=''):
     """Generate the CONECT record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect10.html#CONECT}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect10.html#CONECT}.
 
     CONECT
     ======
@@ -431,7 +465,7 @@ def conect(file, serial='', bonded1='', bonded2='', bonded3='', bonded4=''):
 def end(file):
     """Generate the END record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect11.html#END}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect11.html#END}.
 
     END
     ===
@@ -501,7 +535,7 @@ def end(file):
 def endmdl(file):
     """Generate the ENDMDL record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/v3.3.html}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/v3.3.html}.
 
     ENDMDL
     ======
@@ -591,7 +625,7 @@ def endmdl(file):
 def formul(file, comp_num='', het_id='', continuation='', asterisk='', text=''):
     """Generate the FORMUL record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect4.html#FORMUL}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect4.html#FORMUL}.
 
     FORMUL
     ======
@@ -703,7 +737,7 @@ def formul(file, comp_num='', het_id='', continuation='', asterisk='', text=''):
 def helix(file, ser_num='', helix_id='', init_res_name='', init_chain_id='', init_seq_num='', init_icode='', end_res_name='', end_chain_id='', end_seq_num='', end_icode='', helix_class='', comment='', length=''):
     """Generate the HELIX record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect5.html#HELIX}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect5.html#HELIX}.
 
     HELIX
     =====
@@ -851,7 +885,7 @@ def helix(file, ser_num='', helix_id='', init_res_name='', init_chain_id='', ini
 def het(file, het_id='', chain_id='', seq_num='', icode='', num_het_atoms='', text=''):
     """Generate the HET record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect4.html#HET}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect4.html#HET}.
 
     HET
     ===
@@ -975,7 +1009,7 @@ def het(file, het_id='', chain_id='', seq_num='', icode='', num_het_atoms='', te
 def hetatm(file, serial='', name='', alt_loc='', res_name='', chain_id='', res_seq='', icode='', x='', y='', z='', occupancy=1.0, temp_factor=0.0, element='', charge=''):
     """Generate the HETATM record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect9.html#HETATM}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect9.html#HETATM}.
 
     HETATM
     ======
@@ -1132,7 +1166,7 @@ def hetatm(file, serial='', name='', alt_loc='', res_name='', chain_id='', res_s
 def hetnam(file, continuation='', het_id='', text=''):
     """Generate the HETNAM record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect4.html#HETNAM}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect4.html#HETNAM}.
 
     HETNAM
     ======
@@ -1239,7 +1273,7 @@ def hetnam(file, continuation='', het_id='', text=''):
 def master(file, num_remark=0, num_het=0, num_helix=0, num_sheet=0, num_turn=0, num_site=0, num_xform=0, num_coord=0, num_ter=0, num_conect=0, num_seq=0):
     """Generate the MASTER record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect11.html#MASTER}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect11.html#MASTER}.
 
     MASTER
     ======
@@ -1361,7 +1395,7 @@ def master(file, num_remark=0, num_het=0, num_helix=0, num_sheet=0, num_turn=0,
 def model(file, serial=''):
     """Generate the MODEL record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect9.html#MODEL}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect9.html#MODEL}.
 
     MODEL
     =====
@@ -1495,7 +1529,7 @@ def model(file, serial=''):
 def remark(file, num='', remark=''):
     """Generate the REMARK record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/remarks.html}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/remarks.html}.
 
     REMARK
     ======
@@ -1553,7 +1587,7 @@ def remark(file, num='', remark=''):
 def sheet(file, strand='', sheet_id='', num_strands='', init_res_name='', init_chain_id='', init_seq_num='', init_icode='', end_res_name='', end_chain_id='', end_seq_num='', end_icode='', sense='', cur_atom='', cur_res_name='', cur_chain_id='', cur_res_seq='', cur_icode='', prev_atom='', prev_res_name='', prev_chain_id='', prev_res_seq='', prev_icode=''):
     """Generate the SHEET record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect5.html#SHEET}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect5.html#SHEET}.
 
     SHEET
     =====
@@ -1725,12 +1759,12 @@ def sheet(file, strand='', sheet_id='', num_strands='', init_res_name='', init_c
         _handle_none(end_seq_num),
         _handle_none(end_icode),
         _handle_none(sense),
-        _handle_none(cur_atom),
+        _handle_atom_name(cur_atom),
         _handle_none(cur_res_name),
         _handle_none(cur_chain_id),
         _handle_none(cur_res_seq),
         _handle_none(cur_icode),
-        _handle_none(prev_atom),
+        _handle_atom_name(prev_atom),
         _handle_none(prev_res_name),
         _handle_none(prev_chain_id),
         _handle_none(prev_res_seq),
@@ -1749,7 +1783,7 @@ def sheet(file, strand='', sheet_id='', num_strands='', init_res_name='', init_c
 def ter(file, serial='', res_name='', chain_id='', res_seq='', icode=''):
     """Generate the TER record.
 
-    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/format33/sect9.html#TER}.
+    The following is the PDB v3.3 documentation U{http://www.wwpdb.org/documentation/file-format/format33/sect9.html#TER}.
 
     TER
     ===
