@@ -21,7 +21,7 @@
 
 # Python module imports.
 from minfx.generic import generic_minimise
-from numpy import array, average, dot, float64, std, zeros
+from numpy import array, average, dot, float64, mean, std, zeros
 from numpy.linalg import norm
 from os import F_OK, access, getcwd
 from re import search
@@ -89,7 +89,7 @@ def add_atom(mol_name=None, atom_name=None, res_name=None, res_num=None, pos=[No
         cdp.structure = Internal()
 
     # Add the atoms.
-    cdp.structure.add_atom(mol_name=mol_name, atom_name=atom_name, res_name=res_name, res_num=res_num, pos=pos, element=element, atom_num=atom_num, chain_id=chain_id, segment_id=segment_id, pdb_record=pdb_record)
+    cdp.structure.add_atom(mol_name=mol_name, atom_name=atom_name, res_name=res_name, res_num=res_num, pos=pos, element=element, atom_num=atom_num, chain_id=chain_id, segment_id=segment_id, pdb_record=pdb_record, sort=True)
 
 
 def add_model(model_num=None):
@@ -132,6 +132,13 @@ def assemble_structural_coordinates(pipes=None, models=None, molecules=None, ato
     # Assemble the atomic coordinates of all molecules.
     ids, object_id_list, model_list, molecule_list, atom_pos, mol_names, res_names, res_nums, atom_names, elements, one_letter_codes, num_mols = assemble_atomic_coordinates(objects=objects, object_names=object_names, molecules=molecules, models=models, atom_id=atom_id)
 
+    # No data.
+    if mol_names == []:
+        if atom_id != None:
+            raise RelaxError("No structural data matching the atom ID string '%s' can be found." % atom_id)
+        else:
+            raise RelaxError("No structural data can be found.")
+
     # Are all molecules the same?
     same_mol = True
     for mol in molecule_list:
@@ -177,7 +184,7 @@ def assemble_structural_coordinates(pipes=None, models=None, molecules=None, ato
         for mol_index in range(num_mols):
             res_num_list.append([])
             for i in range(len(one_letter_codes[mol_index])):
-                key = res_nums[mol_index][i].keys()[0]
+                key = list(res_nums[mol_index][i].keys())[0]
                 res_num_list[mol_index].append(res_nums[mol_index][i][key])
 
         # Sequence alignment.
@@ -364,6 +371,40 @@ def atomic_fluctuations(pipes=None, models=None, molecules=None, atom_id=None, m
     correlation_matrix(format=format, matrix=matrix, labels=labels, file=file, dir=dir, force=force)
 
 
+def average_structure(pipes=None, models=None, molecules=None, atom_id=None, set_mol_name=None, set_model_num=None):
+    """Calculate a mean structure.
+
+    @keyword pipes:         The data pipes containing structures to average.
+    @type pipes:            None or list of str
+    @keyword models:        The list of models for each data pipe.  The number of elements must match the pipes argument.  If set to None, then all models will be used.
+    @type models:           None or list of lists of int
+    @keyword molecules:     The list of molecules for each data pipe.  The number of elements must match the pipes argument.
+    @type molecules:        None or list of lists of str
+    @keyword atom_id:       The molecule, residue, and atom identifier string.  This matches the spin ID string format.
+    @type atom_id:          str or None
+    @keyword set_mol_name:  The molecule name for the averaged molecule.
+    @type set_mol_name:     None or str
+    @keyword set_model_num: The model number for the averaged molecule.
+    @type set_model_num:    None or int
+    """
+
+    # Checks.
+    check_pipe()
+
+    # Assemble the structural coordinates.
+    coord, ids, mol_names, res_names, res_nums, atom_names, elements = assemble_structural_coordinates(pipes=pipes, models=models, molecules=molecules, atom_id=atom_id)
+
+    # Calculate the mean structure.
+    struct = mean(coord, axis=0)
+
+    # Place the structural object into the relax data store if needed.
+    if not hasattr(cdp, 'structure'):
+        cdp.structure = Internal()
+
+    # Store the data.
+    cdp.structure.add_coordinates(coord=struct, mol_names=mol_names, res_names=res_names, res_nums=res_nums, atom_names=atom_names, elements=elements, set_mol_name=set_mol_name, set_model_num=set_model_num)
+
+
 def connect_atom(index1=None, index2=None):
     """Connect two atoms.
 
@@ -962,17 +1003,6 @@ def load_spins_multi_mol(spin_id=None, str_id=None, from_mols=None, mol_name_tar
     cdp.N = len(from_mols)
 
 
-def mean():
-    """Calculate the mean structure from all models in the structural data object."""
-
-    # Checks.
-    check_pipe()
-    check_structure()
-
-    # Call the specific code.
-    cdp.structure.mean()
-
-
 def read_gaussian(file=None, dir=None, set_mol_name=None, set_model_num=None, verbosity=1, fail=True):
     """Read structures from a Gaussian log file.
 
@@ -1252,7 +1282,7 @@ def sequence_alignment(pipes=None, models=None, molecules=None, msa_algorithm='C
     for mol_index in range(num_mols):
         res_num_list.append([])
         for i in range(len(one_letter_codes[mol_index])):
-            key = res_nums[mol_index][i].keys()[0]
+            key = list(res_nums[mol_index][i].keys())[0]
             res_num_list[mol_index].append(res_nums[mol_index][i][key])
 
     # MSA.
@@ -1632,7 +1662,7 @@ def web_of_motion(pipes=None, models=None, molecules=None, atom_id=None, file=No
         # Loop over the structures.
         for struct_index in range(len(ids)):
             # Add the atom.
-            web.add_atom(mol_name=mol_names[atom_index], atom_name=atom_names[atom_index], res_name=res_names[atom_index], res_num=res_nums[atom_index], pos=coord[struct_index, atom_index], element=elements[atom_index])
+            web.add_atom(mol_name=mol_names[atom_index], atom_name=atom_names[atom_index], res_name=res_names[atom_index], res_num=res_nums[atom_index], pos=coord[struct_index, atom_index], element=elements[atom_index], sort=False)
 
         # Loop over the structures again, this time twice.
         for k in range(len(ids)):
