@@ -40,6 +40,8 @@ static int num_params, num_times;
 /* Hardcoded parameter indices. */
 static int index_R = 0;
 static int index_I0 = 1;
+static int index_Iinf = 1;
+static int index_inv_Iinf = 2;
 
 /* Variables used for storage during the function calls of optimisation. */
 static double back_calc[MAX_DATA];
