@@ -36,7 +36,7 @@ from gui.string_conv import float_to_gui, str_to_gui
 from gui.uf_objects import Uf_storage; uf_store = Uf_storage()
 from lib.dispersion.variables import EXP_TYPE_R1RHO, MODEL_CR72, MODEL_DPL94, MODEL_IT99, MODEL_LM63, MODEL_NOREX, MODEL_NS_CPMG_2SITE_EXPANDED, MODEL_R2EFF, MODEL_TP02
 from pipe_control.mol_res_spin import spin_loop
-from pipe_control.pipes import switch
+from pipe_control.pipes import get_bundle, switch
 from specific_analyses.relax_disp.data import generate_r20_key
 from status import Status; status = Status()
 from test_suite.gui_tests.base_classes import GuiTestCase
@@ -68,20 +68,7 @@ class Relax_disp(GuiTestCase):
         path = status.install_path + sep + 'test_suite' + sep + 'shared_data' + sep + 'peak_lists' + sep
 
         # Simulate the new analysis wizard, selecting the fixed time CPMG experiment.
-        self.app.gui.analysis.menu_new(None)
-        page = self.app.gui.analysis.new_wizard.wizard.get_page(0)
-        page.select_disp(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-
-        # Get the data.
-        analysis_type, analysis_name, pipe_name, pipe_bundle, uf_exec = self.app.gui.analysis.new_wizard.get_data()
-
-        # Set up the analysis.
-        self.app.gui.analysis.new_analysis(analysis_type=analysis_type, analysis_name=analysis_name, pipe_name=pipe_name, pipe_bundle=pipe_bundle, uf_exec=uf_exec)
-
-        # Alias the analysis.
-        analysis = self.app.gui.analysis.get_page_from_name("Relaxation dispersion")
+        analysis = self.new_analysis_wizard(analysis_type='disp')
 
         # Change the results directory.
         analysis.field_results_dir.SetValue(str_to_gui(ds.tmpdir))
@@ -145,20 +132,7 @@ class Relax_disp(GuiTestCase):
         data_path = status.install_path + sep + 'test_suite' + sep + 'shared_data' + sep + 'dispersion' + sep + 'KTeilum_FMPoulsen_MAkke_2006' + sep + 'acbp_cpmg_disp_101MGuHCl_40C_041223' + sep
 
         # Simulate the new analysis wizard, selecting the fixed time CPMG experiment.
-        self.app.gui.analysis.menu_new(None)
-        page = self.app.gui.analysis.new_wizard.wizard.get_page(0)
-        page.select_disp(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-
-        # Get the data.
-        analysis_type, analysis_name, pipe_name, pipe_bundle, uf_exec = self.app.gui.analysis.new_wizard.get_data()
-
-        # Set up the analysis.
-        self.app.gui.analysis.new_analysis(analysis_type=analysis_type, analysis_name=analysis_name, pipe_name=pipe_name, pipe_bundle=pipe_bundle, uf_exec=uf_exec)
-
-        # Alias the analysis.
-        analysis = self.app.gui.analysis.get_page_from_name("Relaxation dispersion")
+        analysis = self.new_analysis_wizard(analysis_type='disp')
 
         # Change the results directory.
         analysis.field_results_dir.SetValue(str_to_gui(ds.tmpdir))
@@ -211,20 +185,7 @@ class Relax_disp(GuiTestCase):
         """Test catching U{bug #22501<https://gna.org/bugs/index.php?22501>}, 'Close all analyses' raises error."""
 
         # Simulate the new analysis wizard, selecting the fixed time CPMG experiment.
-        self.app.gui.analysis.menu_new(None)
-        page = self.app.gui.analysis.new_wizard.wizard.get_page(0)
-        page.select_disp(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-
-        # Get the data.
-        analysis_type, analysis_name, pipe_name, pipe_bundle, uf_exec = self.app.gui.analysis.new_wizard.get_data()
-
-        # Set up the analysis.
-        self.app.gui.analysis.new_analysis(analysis_type=analysis_type, analysis_name=analysis_name, pipe_name=pipe_name, pipe_bundle=pipe_bundle, uf_exec=uf_exec)
-
-        # Alias the analysis.
-        analysis = self.app.gui.analysis.get_page_from_name("Relaxation dispersion")
+        analysis = self.new_analysis_wizard(analysis_type='disp')
 
         # Closure.
         self.app.gui.analysis.delete_analysis(0)
@@ -239,20 +200,7 @@ class Relax_disp(GuiTestCase):
         data_path_800 = data_path + sep + '800_MHz' + sep
 
         # Simulate the new analysis wizard, selecting the fixed time CPMG experiment.
-        self.app.gui.analysis.menu_new(None)
-        page = self.app.gui.analysis.new_wizard.wizard.get_page(0)
-        page.select_disp(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-
-        # Get the data.
-        analysis_type, analysis_name, pipe_name, pipe_bundle, uf_exec = self.app.gui.analysis.new_wizard.get_data()
-
-        # Set up the analysis.
-        self.app.gui.analysis.new_analysis(analysis_type=analysis_type, analysis_name=analysis_name, pipe_name=pipe_name, pipe_bundle=pipe_bundle, uf_exec=uf_exec)
-
-        # Alias the analysis.
-        analysis = self.app.gui.analysis.get_page_from_name("Relaxation dispersion")
+        analysis = self.new_analysis_wizard(analysis_type='disp')
 
         # Change the results directory.
         analysis.field_results_dir.SetValue(str_to_gui(ds.tmpdir))
@@ -473,20 +421,7 @@ class Relax_disp(GuiTestCase):
         path = status.install_path + sep + 'test_suite' + sep + 'shared_data' + sep + 'peak_lists' + sep
 
         # Simulate the dispersion analysis wizard.
-        self.app.gui.analysis.menu_new(None)
-        page = self.app.gui.analysis.new_wizard.wizard.get_page(0)
-        page.select_disp(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-
-        # Get the data.
-        analysis_type, analysis_name, pipe_name, pipe_bundle, uf_exec = self.app.gui.analysis.new_wizard.get_data()
-
-        # Set up the analysis.
-        self.app.gui.analysis.new_analysis(analysis_type=analysis_type, analysis_name=analysis_name, pipe_name=pipe_name, pipe_bundle=pipe_bundle, uf_exec=uf_exec)
-
-        # Alias the analysis.
-        analysis = self.app.gui.analysis.get_page_from_name("Relaxation dispersion")
+        analysis = self.new_analysis_wizard(analysis_type='disp')
 
         # Change the results directory.
         analysis.field_results_dir.SetValue(str_to_gui(ds.tmpdir))
@@ -550,20 +485,7 @@ class Relax_disp(GuiTestCase):
         data_path = status.install_path + sep+'test_suite'+sep+'shared_data'+sep+'dispersion'+sep+'Kjaergaard_et_al_2013'+sep
 
         # Simulate the new analysis wizard, selecting the fixed time CPMG experiment.
-        self.app.gui.analysis.menu_new(None)
-        page = self.app.gui.analysis.new_wizard.wizard.get_page(0)
-        page.select_disp(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-
-        # Get the data.
-        analysis_type, analysis_name, pipe_name, pipe_bundle, uf_exec = self.app.gui.analysis.new_wizard.get_data()
-
-        # Set up the analysis.
-        self.app.gui.analysis.new_analysis(analysis_type=analysis_type, analysis_name=analysis_name, pipe_name=pipe_name, pipe_bundle=pipe_bundle, uf_exec=uf_exec)
-
-        # Alias the analysis.
-        analysis = self.app.gui.analysis.get_page_from_name("Relaxation dispersion")
+        analysis = self.new_analysis_wizard(analysis_type='disp')
 
         # Change the results directory.
         analysis.field_results_dir.SetValue(str_to_gui(ds.tmpdir))
@@ -613,20 +535,7 @@ class Relax_disp(GuiTestCase):
         data_path = status.install_path + sep+'test_suite'+sep+'shared_data'+sep+'dispersion'+sep+'r1rho_off_res_tp02'+sep
 
         # Simulate the new analysis wizard, selecting the fixed time CPMG experiment.
-        self.app.gui.analysis.menu_new(None)
-        page = self.app.gui.analysis.new_wizard.wizard.get_page(0)
-        page.select_disp(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-        self.app.gui.analysis.new_wizard.wizard._go_next(None)
-
-        # Get the data.
-        analysis_type, analysis_name, pipe_name, pipe_bundle, uf_exec = self.app.gui.analysis.new_wizard.get_data()
-
-        # Set up the analysis.
-        self.app.gui.analysis.new_analysis(analysis_type=analysis_type, analysis_name=analysis_name, pipe_name=pipe_name, pipe_bundle=pipe_bundle, uf_exec=uf_exec)
-
-        # Alias the analysis.
-        analysis = self.app.gui.analysis.get_page_from_name("Relaxation dispersion")
+        analysis = self.new_analysis_wizard(analysis_type='disp')
 
         # Change the results directory.
         analysis.field_results_dir.SetValue(str_to_gui(ds.tmpdir))
@@ -795,7 +704,7 @@ class Relax_disp(GuiTestCase):
         r20_key2 = generate_r20_key(exp_type=EXP_TYPE_R1RHO, frq=800e6)
 
         # Switch to the 'TP02' model data pipe, then check for each spin.
-        switch("%s - %s" % ('TP02', pipe_bundle))
+        switch("%s - %s" % ('TP02', get_bundle()))
         spin_index = 0
         for spin, spin_id in spin_loop(return_id=True):
             # Printout.
