@@ -22,4 +22,4 @@ structure.get_pos("@H")
 interatom.unit_vectors()
 diffusion_tensor.init(params=(1e-08, 0, 0, 0, 0, 0), time_scale=1.0, d_scale=1.0, angle_units='deg', param_types=0, spheroid_type=None, fixed=False)
 fix(element='all_spins', fixed=True)
-grid_search(lower=None, upper=None, inc=6, constraints=True, verbosity=1)
+minimise.grid_search(lower=None, upper=None, inc=6, constraints=True, verbosity=1)
